;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "wttrin" "20251113.2014"
  "Emacs Frontend for Service wttr.in."
  '((emacs       "24.4")
    (xterm-color "1.0"))
  :url "https://github.com/cjennings/emacs-wttrin"
  :commit "bf989bb594680eb2e3b69f55752353aa33cb47bb"
  :revdesc "bf989bb59468"
  :keywords '("weather" "wttrin" "games")
  :maintainers '(("Craig Jennings" . "c@cjennings.net")))
